### 开始使用

PDFMathTranslate 是一款强大的 PDF 翻译工具。您可以通过多种方式安装并开始使用此工具。

---

### 如何安装

1. [**Windows 可执行文件**](./如何安装_winexe.md) <small>推荐 Windows 用户使用</small>  
2. [**Docker**](./如何安装_docker.md) <small>推荐 Linux 用户使用</small>  
3. [**uv** (Python 包管理工具)](./如何安装_uv.md) <small>推荐 macOS 用户使用</small>

---

### 如何使用

1. [使用 **WebUI**](./USAGE_webui.md)  
2. [使用 **Zotero 插件**](https://github.com/guaguastandup/zotero-pdf2zh)（第三方程序）  
3. [使用 **命令行**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>本页面的部分内容由 GPT 翻译，可能包含错误。</small></h6>